@@ -211,12 +211,12 @@ def batch_create_data_rows(client, dataset, global_key_to_upload_dict, skip_dupl
     upload_results = []
     for i in range(0,len(upload_list),batch_size):
         batch = upload_list[i:] if i + batch_size >= len(upload_list) else upload_list[i:i+batch_size]
+        print(batch[0]
         task = dataset.create_data_rows(batch)
         task.wait_till_done()
-        errors = task.errors
-        if errors:
-            print(f'Data Row Creation Error: {errors}')
-            return errors
+        if task.errors:
+            print(f'Data Row Creation Error: {task.errors}')
+            return task.errors
     return upload_results
 
 
